diff --git a/python/s2snow/snow_detector.py b/python/s2snow/snow_detector.py
index 5be866292ba89174ec13554336df2396861b20aa..12d4a66c65ad7ba996f217b69fb16c60df38073d 100644
--- a/python/s2snow/snow_detector.py
+++ b/python/s2snow/snow_detector.py
@@ -731,7 +731,7 @@ class snow_detector:
 
         if snow_fraction > self.fsnow_total_lim:
             # Test zs value (-1 means that no zs elevation was found)
-            if self.zs != -1:
+            if self.zs != -1000:
                 #~ # NDSI threshold again
                 #~ ndsi_formula = "(im1b" + str(self.nGreen) + "-im1b" + str(self.nSWIR) + \
                                #~ ")/(im1b" + str(self.nGreen) + "+im1b" + str(self.nSWIR) + ")"
diff --git a/src/histo_utils.cxx b/src/histo_utils.cxx
index e078be7e26d86b1a4156871b9c3f483f1ad287aa..9f5f49943b51e234c710785e5fe99d8a4dacf0f2 100644
--- a/src/histo_utils.cxx
+++ b/src/histo_utils.cxx
@@ -224,8 +224,8 @@ short compute_snowline_internal(const itk::VectorImage<short, 2>::Pointer compos
 
     myfile << "Number of bins=0" << std::endl;
     myfile.close();
-    // Return -1 as no zs is found in this case
-    return -1;
+    // Return -1000 as no zs is found in this case
+    return -1OOO;
     }
 
   
@@ -248,7 +248,7 @@ short compute_snowline_internal(const itk::VectorImage<short, 2>::Pointer compos
     {
     print_histogram(*histogram,histo_file);
     }
-  short snowline = -1;
+  short snowline = -1000;
   if(reverse)
     {
     for (int i=histogram->GetSize()[0]-1; i>=0; i--)
@@ -267,7 +267,7 @@ short compute_snowline_internal(const itk::VectorImage<short, 2>::Pointer compos
         return snowline;
       }
     }
   // snow line not found -1
   return snowline;
 }
@@ -267,7 +267,7 @@ short compute_snowline_internal(const itk::VectorImage<short, 2>::Pointer compos
       }
     }
-  // snow line not found -1
+  // snow line not found -1000
   return snowline;
 }